import chai from 'chai';
import SinonChai from 'sinon-chai';
import { SnapshotPlugin } from './snapshot';
export async function setupChai(config) {
    chai.use(SinonChai);
    chai.use(await SnapshotPlugin({
        rootDir: config.rootDir || process.cwd(),
        update: config.updateSnapshot,
    }));
    // Jest Compact
    // TODO: add more https://jestjs.io/docs/expect
    chai.use((chai, utils) => {
        const proto = chai.Assertion.prototype;
        utils.addMethod(proto, 'toEqual', function (expected) {
            return this.eql(expected);
        });
        utils.addMethod(proto, 'toStrictEqual', function (expected) {
            return this.equal(expected);
        });
        utils.addMethod(proto, 'toBe', function (expected) {
            return this.be(expected);
        });
        utils.addMethod(proto, 'toContain', function (item) {
            return this.contain(item);
        });
        utils.addMethod(proto, 'toBeTruthy', function () {
            const obj = utils.flag(this, 'object');
            this.assert(Boolean(obj), 'expected #{this} to be truthy', 'expected #{this} to not be truthy', obj);
        });
        utils.addMethod(proto, 'toFalsy', function () {
            const obj = utils.flag(this, 'object');
            this.assert(!obj, 'expected #{this} to be falsy', 'expected #{this} to not be falsy', obj);
        });
        utils.addMethod(proto, 'toBeNaN', function () {
            return this.be.NaN;
        });
        utils.addMethod(proto, 'toBeUndefined', function () {
            return this.be.undefined;
        });
        utils.addMethod(proto, 'toBeNull', function () {
            return this.be.null;
        });
        utils.addMethod(proto, 'toBeDefined', function () {
            return this.not.be.undefined;
        });
    });
}
export { assert, should, expect } from 'chai';
